pub struct Settings {
pub url: String,
pub project_id: String,
pub max_validity_secs: Option<u64>,
pub time_tolerance_secs: Option<u64>,
pub accept_future: Option<bool>,
pub bearer_pubkey: Option<String>,
}Fields
url: StringThe URL to retrieve rotating jwks from Firebase
project_id: StringFirebase project number
max_validity_secs: Option<u64>The maximum amount of time in seconds after a token has expired to allow a token to verify
time_tolerance_secs: Option<u64>How much clock in seconds to tolerate when verifying token timestamps; default 15 min
accept_future: Option<bool>Accepts tokens in the future
bearer_pubkey: Option<String>Bypass Firebase Token with self-issued JWT bearer tokens The base58-encoded address of, or the path to, the PEM-encoded Ed2559 public signing key
Implementations
Sourceimpl Settings
impl Settings
pub fn max_validity(&self) -> Option<Duration>
pub fn time_tolerance(&self) -> Option<Duration>
pub fn bearer_pubkey(&self) -> Option<Result<Ed25519PublicKey, Error>>